@@ -1,12 +1,10 @@
 package Net::IDN::Encode;
 
-require 5.006;
-
 use strict;
 use utf8;
 use warnings;
 
-our $VERSION = "2.499_20180929";
+our $VERSION = "2.001";
 $VERSION = eval $VERSION;
 
 use Carp;
@@ -25,40 +23,34 @@ our %EXPORT_TAGS = (
     ],
   '_var' => [
       '$IDNA_PREFIX',
-      'IsIDNADot',
-      'IsIDNAAtsign',
+      '$IDNA_DOT',
+      '$IDNA_ATSIGN',
     ]
 );
 Exporter::export_ok_tags(keys %EXPORT_TAGS);
 
-use Net::IDN::Punycode 1.102 ();
+use Net::IDN::Punycode 1 ();
 
-our $IDNA_PREFIX = 'xn--';
-sub IsIDNADot 	{ "002E\n3002\nFF0E\nFF61" }
-sub IsIDNAAtsign{ "0040\nFE6B\nFF20" }
+our ($IDNA_PREFIX,$IDNA_DOT,$IDNA_ATSIGN);
+*IDNA_PREFIX 	= \'xn--';
+*IDNA_DOT	= \qr/[\.。．｡]/;
+*IDNA_ATSIGN	= \qr/[\@＠]/;
 
 require Net::IDN::UTS46; # after declaration of vars!
 
 sub to_ascii {
   my($label,%param) = @_;
-  croak 'Invalid label' if $label =~ m/\p{IsIDNADot}/o;
-
-  if($label =~ m/\P{ASCII}/o) {
-    $label = Net::IDN::UTS46::to_ascii(@_);
-  } else {
-    croak 'label empty' if length($label) < 1;
-    croak 'label too long' if length($label) > 63;
-  }
+  croak 'Invalid label' if $label =~ m/$IDNA_DOT/o;
+  eval { $label = Net::IDN::UTS46::to_ascii(@_) };
+  die $@ if $@ and ($label =~ m/\P{ASCII}/);
   return $label;
 }
 
 sub to_unicode {
   my($label,%param) = @_;
-  croak 'Invalid label' if $label =~ m/\p{IsIDNADot}/o;
-
-  if($label =~ m/\P{ASCII}|^(?:(?i)$IDNA_PREFIX)/o) {
-    $label = Net::IDN::UTS46::to_unicode(@_);
-  }
+  croak 'Invalid label' if $label =~ m/$IDNA_DOT/o;
+  eval { $label = Net::IDN::UTS46::to_unicode(@_) };
+  die $@ if $@ and ($label =~ m/\P{ASCII}/);
   return $label;
 }
 
@@ -69,7 +61,7 @@ sub _domain {
   my $even_odd = 1;
   return join '',
     map { $even_odd++ % 2 ? $to_function->($_, %param) : $ascii ? '.' : $_ }
-      split /(\p{IsIDNADot})/o, $domain;
+      split /($IDNA_DOT)/o, $domain;
 }
 
 sub _email {
@@ -77,12 +69,12 @@ sub _email {
   return $email if !defined($email) || $email eq '';
 
   $email =~ m/^(
-	(?(?!\p{IsIDNAAtsign}|").|(?!))+
+	(?(?!$IDNA_ATSIGN|").|(?!))+
 	|
 	"(?:(?:[^"]|\\.)*[^\\])?"
       )
       (?:
-	(\p{IsIDNAAtsign})
+	($IDNA_ATSIGN)
    	(?:([^\[\]]*)|(\[.*\]))?
       )?$/xo || croak "Invalid email address";
   my($local_part,$at,$domain,$domain_literal) = ($1,$2,$3);
@@ -129,22 +121,11 @@ decoding Internationalized Domain Names (IDNs).
 IDNs use characters drawn from a large repertoire (Unicode), but
 IDNA allows the non-ASCII characters to be represented using only
 the ASCII characters already allowed in so-called host names today
-(letter-digit-hyphen, C</[A-Z0-9-]/i>).
+(letter-digit-hypen, C</[A-Z0-9-]/i>).
 
 Use this module if you just want to convert domain names (or email addresses),
 using whatever IDNA standard is the best choice at the moment.
 
-You should be familiar with Unicode support in perl, as this module expects
-correctly encoded input. See L<perlunitut>, L<perluniintro> and L<perlunicode>
-for details.
-
-=head1 UNICODE VERSION
-
-To convert labels correctly between Unicode and ASCII, each character in the
-label must be present in the Unicode version supported by your perl.
-Consequently, this module will refuse to convert labels with new Unicode
-characters on older perl versions (see below).
-
 =head1 FUNCTIONS
 
 By default, this module does not export any subroutines. You may
@@ -169,17 +150,12 @@ This function takes the following optional parameters (C<%param>):
 
 =item AllowUnassigned
 
-(boolean) If set to a true value, code points that are unassigned in the
-Unicode version supported by your perl are allowed. This is an extension over
-UTS #46.
-
-While this increases the number of labels that can be converted successfully
-(especially on older perls) and may thus maximizes the compatibility with
-domain names created under future versions of Unicode, it also introduces the
-risk of incorrect conversions.  Characters added in later versions of Unicode
-might have properties that affect the conversion; if these properties are not
-known on your version of perl, you might therefore end up with an incorrect
-conversion.
+(boolean) If set to a true value, unassigned code points in the label are
+allowed. While maximizing the compatibility with future versions of Unicode
+and/or IDNA, this option is also dangerous: Characters added in future versions
+of Unicode might have properties that affect the conversion; you might
+therefore end up with a conversion that is incompatible with later standards.
+Therefore, set this to false unless you know what you are doing.
 
 The default is false.
 
@@ -229,8 +205,8 @@ This function takes the following optional parameters (C<%param>):
 
 =item UseSTD3ASCIIRules
 
-See C<to_unicode> above. Please note that there is no need for
-C<TransitionalProcessing> for C<to_unicode>.
+See C<to_unicode> above. Please note that there is no C<TransitionalProcessing>
+for C<to_unicode>.
 
 =back
 
@@ -239,7 +215,7 @@ domain names). Use C<domain_to_unicode> instead.
 
 =item domain_to_ascii( $label, %param )
 
-Converts all labels of the hostname C<$domain> (with labels separated by dots)
+Converts all labels of the hostname C<$domain> (with labels seperated by dots)
 to ASCII (using C<to_ascii>). Will throw an exception on invalid input.
 
 This function takes the following optional parameters (C<%param>):
@@ -268,7 +244,7 @@ ideographic full stop).
 
 =item domain_to_unicode( $domain, %param )
 
-Converts all labels of the hostname C<$domain> (with labels separated by dots)
+Converts all labels of the hostname C<$domain> (with labels seperated by dots)
 to Unicode. Will throw an exception on invalid input.
 
 This function takes the same optional parameters as C<domain_to_ascii>,
@@ -304,9 +280,8 @@ This function currently does not handle internationalization of the local-part
 conversion for the local-part, should one be standardized.
 
 This function will convert the at sign to ASCII, i.e. to U+0040 (commercial
-at), as well as label separators.  The following characters are recognized as at
-signs: U+0040 (commercial at), U+FE6B (small commercial at) and U+FF20
-(fullwidth commercial at).
+at), as well as label separators.  The follwing characters are recognized as at
+signs: U+0040 (commercial at), U+FF20 (fullwidth commercial at).
 
 =item email_to_unicode( $email, %param )
 
@@ -321,9 +296,8 @@ This function currently does not handle internationalization of the local-part
 from ASCII for the local-part, should one be standardized.
 
 This function will preserve the original version of at signs (and label
-separators). The following characters are recognized as at signs: U+0040
-(commercial at), U+FE6B (small commercial at) and U+FF20 (fullwidth commercial
-at).
+separators). The follwing characters are recognized as at signs: U+0040
+(commercial at), U+FF20 (fullwidth commercial at).
 
 =back
 
@@ -333,7 +307,7 @@ Claus FE<auml>rber <CFAERBER@cpan.org>
 
 =head1 LICENSE
 
-Copyright 2007-2014 Claus FE<auml>rber.
+Copyright 2007-2012 Claus FE<auml>rber.
 
 This library is free software; you can redistribute it and/or modify
 it under the same terms as Perl itself.
